Package {packageRankWrapperDriver}


Version: 1.0
Date: 2026-07-30
Title: Wrapper to Facilitate Tabulating the Daily Quartile Ranking of Downloads of your Packages
Maintainer: Barry Zeeberg <barryz2013@gmail.com>
Author: Barry Zeeberg [aut, cre]
Depends: R (≥ 4.2.0)
LazyData: true
Imports: packageRank, pkgsearch
Description: This is a convenient program to tabulate the daily quartile ranking of downloads of your packages. It is designed to be slightly more convenient than the several similar programs. You do not need to keep typing in the names of your packages each time you want to run this.
License: GPL-2 | GPL-3 [expanded from: GPL (≥ 2)]
Encoding: UTF-8
VignetteBuilder: knitr
Suggests: knitr, rmarkdown, testthat (≥ 3.0.0)
Config/testthat/edition: 3
NeedsCompilation: no
Repository: CRAN
Config/roxygen2/version: 8.0.0
Packaged: 2026-07-31 00:22:05 UTC; barryzeeberg
Date/Publication: 2026-08-07 19:40:02 UTC

packageRankSummary

Description

wrapper to invoke packageRank()

Usage

packageRankSummary(l, dates)

Arguments

l

return value of packageRankWrapper()

dates

vector of character string like "2026-07-05"

Value

returns a summary of packageRank()

Examples

l<-packageRankSummary(x_l,dates=c("2026-07-05","2026-07-06"))


packageRankWrapper

Description

wrapper to invoke packageRank()

Usage

packageRankWrapper(author, date)

Arguments

author

character string author last name

date

character string like "2026-07-05"

Value

returns a portion of the returned value of packageRank()

Examples


# takes too long for CRAN test
l<-packageRankWrapper(author="Zeeberg",date="2026-07-05")



packageRankWrapperDriver

Description

driver to invoke packageRankWrapper()

Usage

packageRankWrapperDriver(author, date_start, date_end)

Arguments

author

character string author last name

date_start

character string like "2026-07-05"

date_end

character string like "2026-07-05"

Value

returns a list whose components are return value of packageRankWrapper()

Examples


# takes too long for CRAN test
l<-packageRankWrapperDriver(author="Zeeberg",date_start="2026-07-05",date_end="2026-07-06")



packageRankWrapperDriver data sets

Description

packageRankWrapperDriver data sets

Usage

data(x_l)